@@ -15,8 +15,7 @@
 #' @return A dibble.
 #'
 #' @export
-dibble <- function(...,
-                   .dim_names = NULL) {
+dibble <- function(..., .dim_names = NULL) {
   args <- list2(...)
 
   old_dim_names <- union_dim_names(purrr::map(unname(args), dimnames))
@@ -33,25 +32,24 @@ dibble <- function(...,
     undibble(broadcast(x, new_dim_names))
   }
 
-  args <- purrr::map2(unname(args), names2(args),
-                      function(x, nm) {
-                        if (is_tbl_ddf(x)) {
-                          x <- purrr::modify(as.list(x), fun)
+  args <- purrr::map2(unname(args), names2(args), function(x, nm) {
+    if (is_tbl_ddf(x)) {
+      x <- purrr::modify(as.list(x), fun)
 
-                          if (nm != "") {
-                            stopifnot(
-                              is_scalar_list(x)
-                            )
+      if (nm != "") {
+        stopifnot(
+          is_scalar_list(x)
+        )
 
-                            names(x) <- nm
-                          }
-                          x
-                        } else {
-                          x <- list(fun(x))
-                          names(x) <- nm
-                          x
-                        }
-                      })
+        names(x) <- nm
+      }
+      x
+    } else {
+      x <- list(fun(x))
+      names(x) <- nm
+      x
+    }
+  })
   args <- list_unchop(args)
 
   if (!is_named(args)) {
@@ -76,15 +74,13 @@ dibble <- function(...,
 #' @return A dibble.
 #'
 #' @export
-dibble_by <- function(x, ...,
-                      .names_sep = NULL) {
+dibble_by <- function(x, ..., .names_sep = NULL) {
   args <- enquos(...)
 
   # pack data
   nms <- names2(args)
   loc <- nms != ""
-  x <- tidyr::pack(x, !!!args[loc],
-                   .names_sep = .names_sep)
+  x <- tidyr::pack(x, !!!args[loc], .names_sep = .names_sep)
   args[loc] <- as_quosures(nms[loc])
   args <- unname(args)
 
@@ -126,16 +122,14 @@ as_dibble.rowwise_df <- function(x, ...) {
     !vec_duplicate_any(haystack)
   )
 
-  dim_names <- purrr::map(haystack, unique)
+  dim_names <- purrr::map(haystack, vctrs::vec_unique)
   dim <- list_sizes_unnamed(dim_names)
 
   needles <- expand_grid_col_major(dim_names)
-  x <- vec_slice(x[!names(x) %in% axes],
-                 vec_match(needles, haystack))
-  x <- purrr::map(x,
-                  function(x) {
-                    array(x, dim)
-                  })
+  x <- vec_slice(x[!names(x) %in% axes], vec_match(needles, haystack))
+  x <- purrr::map(x, function(x) {
+    array(x, dim)
+  })
   new_tbl_ddf(x, dim_names)
 }
 
@@ -200,9 +194,11 @@ as_tibble_dibble <- function(x, n) {
   }
 
   if (is_ddf_col(x)) {
-    out <- vec_cbind(dim_names,
-                     !!n := fun(undibble(x)),
-                     .name_repair = "check_unique")
+    out <- vec_cbind(
+      dim_names,
+      !!n := fun(undibble(x)),
+      .name_repair = "check_unique"
+    )
   } else {
     out <- purrr::modify(undibble(x), fun)
 
@@ -215,9 +211,7 @@ as_tibble_dibble <- function(x, n) {
       names(out) <- n[names(out)]
     }
 
-    out <- vec_cbind(dim_names, !!!out,
-                     .name_repair = "check_unique")
-
+    out <- vec_cbind(dim_names, !!!out, .name_repair = "check_unique")
   }
   out
 }
@@ -239,27 +233,22 @@ aperm_dibble <- function(a, perm, ...) {
   class <- class(a)
   if (is_ddf_col(a)) {
     a <- aperm(as.array(a), perm, ...)
-    new_ddf_col(a, new_dim_names,
-                class = class)
+    new_ddf_col(a, new_dim_names, class = class)
   } else {
-    a <- purrr::modify(undibble(a),
-                       function(x) {
-                         aperm(x, perm, ...)
-                       })
-    new_tbl_ddf(a, new_dim_names,
-                class = class)
+    a <- purrr::modify(undibble(a), function(x) {
+      aperm(x, perm, ...)
+    })
+    new_tbl_ddf(a, new_dim_names, class = class)
   }
 }
 
 
-
 # Verbs -------------------------------------------------------------------
 
 slice_dibble <- function(.data, ...) {
-  locs <- purrr::modify(list2(...),
-                        function(x) {
-                          x %||% missing_arg()
-                        })
+  locs <- purrr::modify(list2(...), function(x) {
+    x %||% missing_arg()
+  })
   nms <- names2(locs)
 
   dim_names <- dimnames(.data)
@@ -273,30 +262,30 @@ slice_dibble <- function(.data, ...) {
   names(locs)[nms == ""] <- axes[!axes %in% nms]
   locs <- locs[axes]
 
-  dim_names <- purrr::map2(dim_names, locs,
-                           function(x, i) {
-                             if (is_missing(i)) {
-                               x
-                             } else {
-                               vec_slice(x, i)
-                             }
-                           })
+  dim_names <- purrr::map2(dim_names, locs, function(x, i) {
+    if (is_missing(i)) {
+      x
+    } else {
+      vec_slice(x, i)
+    }
+  })
   names(dim_names) <- axes
 
   class <- class(.data)
   if (is_ddf_col(.data)) {
-    new_ddf_col(exec(`[`, .data, !!!locs,
-                     drop = FALSE),
-                dim_names = dim_names,
-                class = class)
+    new_ddf_col(
+      exec(`[`, .data, !!!locs, drop = FALSE),
+      dim_names = dim_names,
+      class = class
+    )
   } else if (is_tbl_ddf(.data)) {
-    new_tbl_ddf(purrr::modify(undibble(.data),
-                              function(x) {
-                                exec(`[`, x, !!!locs,
-                                     drop = FALSE)
-                              }),
-                dim_names = dim_names,
-                class = class)
+    new_tbl_ddf(
+      purrr::modify(undibble(.data), function(x) {
+        exec(`[`, x, !!!locs, drop = FALSE)
+      }),
+      dim_names = dim_names,
+      class = class
+    )
   }
 }
 
@@ -359,10 +348,9 @@ filter_dibble <- function(.data, ...) {
   args <- enquos(...)
   dim_names <- dimnames(.data)
   axes <- names(dim_names)
-  idxs <- purrr::map_int(unname(args),
-                         function(x) {
-                           find_index_check(x, axes)
-                         })
+  idxs <- purrr::map_int(unname(args), function(x) {
+    find_index_check(x, axes)
+  })
 
   size <- vec_size(dim_names)
   locs <- vec_init(list(), vec_size(dim_names))
@@ -394,24 +382,27 @@ find_index_check <- function(x, names) {
 find_index <- function(x, names) {
   if (is_atomic(x)) {
     integer()
-  } else if (is_symbol(x) || x[[1L]] == "$") {
+  } else if (is_symbol(x) || as_name(x[[1L]]) %in% c("$", "[[")) {
     which(head_symbol(x) == names)
   } else {
     stopifnot(is_call(x))
 
-    out <- purrr::map(as.list(x[-1L]),
-                      \(x) find_index(x,
-                                      names = names))
+    out <- purrr::map(as.list(x[-1L]), \(x) find_index(x, names = names))
     list_unchop(out)
   }
 }
 
 head_symbol <- function(x) {
-  while (!is_symbol(x)) {
+  while (!is.null(x) && !is_symbol(x)) {
     lhs <- f_lhs(x)
 
-    if (lhs == ".data") {
+    if (is.null(lhs)) {
+      x <- NULL
+    } else if (lhs == ".data") {
       x <- f_rhs(x)
+      if (is.character(x)) {
+        x <- rlang::ensym(x)
+      }
     } else {
       x <- lhs
     }
@@ -429,9 +420,7 @@ print_dibble <- function(x, n, ...) {
 format_dibble <- function(x, n, ...) {
   n <- get_n_print(n, nrow(x))
 
-  setup <- tbl_format_setup(x,
-                            n = n,
-                            ...)
+  setup <- tbl_format_setup(x, n = n, ...)
   header <- tbl_format_header(x, setup)
   body <- tbl_format_body(x, setup)
   footer <- tbl_format_footer(x, setup)
@@ -441,10 +430,11 @@ format_dibble <- function(x, n, ...) {
 tbl_format_setup_dibble <- function(x, n, ...) {
   size_dim <- prod(list_sizes_unnamed(dimnames(x)))
 
-  setup <- tbl_format_setup(tibble::as_tibble(head_dibble(x,
-                                                          n = n)),
-                            n = n,
-                            ...)
+  setup <- tbl_format_setup(
+    tibble::as_tibble(head_dibble(x, n = n)),
+    n = n,
+    ...
+  )
   setup$tbl_sum <- tbl_sum(x)
   rows_total_old <- setup$rows_total
   rows_total_new <- size_dim
