@@ -13,23 +13,21 @@ as_dim_names <- function(x, dim_names) {
     )
 
     loc <- names2(x) == ""
-    nms <- purrr::map_chr(x[loc],
-                          function(x) {
-                            stopifnot(
-                              is_scalar_character(x)
-                            )
-                            x
-                          })
+    nms <- purrr::map_chr(x[loc], function(x) {
+      stopifnot(
+        is_scalar_character(x)
+      )
+      x
+    })
     x[loc] <- list(NULL)
     names(x)[loc] <- nms
   }
 
   stopifnot(
     is_named(x),
-    purrr::every(x,
-                 function(x) {
-                   is.null(x) || !vec_duplicate_any(x)
-                 })
+    purrr::every(x, function(x) {
+      is.null(x) || !vec_duplicate_any(x)
+    })
   )
 
   new_axes <- names(x)
@@ -40,14 +38,13 @@ as_dim_names <- function(x, dim_names) {
 
   dim_names <- dim_names[vec_match(new_axes, old_axes)]
 
-  x <- purrr::map2(x, dim_names,
-                   function(x, dim_name) {
-                     x <- x %||% unique(dim_name)
-                     stopifnot(
-                       !is.null(x)
-                     )
-                     x
-                   })
+  x <- purrr::map2(x, dim_names, function(x, dim_name) {
+    x <- x %||% vctrs::vec_unique(dim_name)
+    stopifnot(
+      !is.null(x)
+    )
+    x
+  })
   names(x) <- new_axes
   x
 }
@@ -59,11 +56,15 @@ is_dim_names <- function(x) {
 union_dim_names <- function(x) {
   x <- list_unchop(x)
   nms <- names(x)
-  nms_unique <- unique(nms)
-  out <- purrr::map(nms_unique,
-                    function(nm_unique) {
-                      unique(list_unchop(unname(x[nms == nm_unique])))
-                    })
+  nms_unique <- if (is.null(nms)) {
+    NULL
+  } else {
+    vctrs::vec_unique(nms)
+  }
+
+  out <- purrr::map(nms_unique, function(nm_unique) {
+    vctrs::vec_unique(list_unchop(unname(x[nms == nm_unique])))
+  })
   names(out) <- nms_unique
   out
 }
@@ -77,8 +78,7 @@ intersect_dim_names <- function(x) {
 }
 
 diff_dim_names <- function(x) {
-  purrr::modify(purrr::list_transpose(x, simplify = FALSE),
-                function(x) {
-                  purrr::reduce(x, set_diff)
-                })
+  purrr::modify(purrr::list_transpose(x, simplify = FALSE), function(x) {
+    purrr::reduce(x, set_diff)
+  })
 }
