@@ -2,12 +2,8 @@ test_that("pmax() and pmin() work", {
   x <- c(1, 2, 3, NA, 5, 6)
   y <- c(3, 2, 1, 5, NA, 6)
 
-  x_tbl_ddf <- dibble(x = x,
-                      .dim_names = list(axis1 = 1:2,
-                                        axis2 = 1:3))
-  y_tbl_ddf <- dibble(y = y,
-                      .dim_names = list(axis1 = 1:2,
-                                        axis2 = 1:3))
+  x_tbl_ddf <- dibble(x = x, .dim_names = list(axis1 = 1:2, axis2 = 1:3))
+  y_tbl_ddf <- dibble(y = y, .dim_names = list(axis1 = 1:2, axis2 = 1:3))
   x_ddf_col <- x_tbl_ddf$x
   y_ddf_col <- y_tbl_ddf$y
 
@@ -16,13 +12,17 @@ test_that("pmax() and pmin() work", {
 
   expect_equal(as.array(pmax(x_tbl_ddf, y_tbl_ddf)), pmax(x_arr, y_arr))
   expect_equal(as.array(pmax(x_ddf_col, y_ddf_col)), pmax(x_arr, y_arr))
-  expect_equal(as.array(pmax(x_ddf_col, y_ddf_col, na.rm = TRUE)),
-               pmax(x_arr, y_arr, na.rm = TRUE))
+  expect_equal(
+    as.array(pmax(x_ddf_col, y_ddf_col, na.rm = TRUE)),
+    pmax(x_arr, y_arr, na.rm = TRUE)
+  )
 
   expect_equal(as.array(pmin(x_tbl_ddf, y_tbl_ddf)), pmin(x_arr, y_arr))
   expect_equal(as.array(pmin(x_ddf_col, y_ddf_col)), pmin(x_arr, y_arr))
-  expect_equal(as.array(pmin(x_ddf_col, y_ddf_col, na.rm = TRUE)),
-               pmin(x_arr, y_arr, na.rm = TRUE))
+  expect_equal(
+    as.array(pmin(x_ddf_col, y_ddf_col, na.rm = TRUE)),
+    pmin(x_arr, y_arr, na.rm = TRUE)
+  )
 
   # Test that the class is preserved
   class(x_tbl_ddf) <- c("my_class", class(x_tbl_ddf))
