@@ -1,7 +1,5 @@
 test_that("nrow-ncol", {
-  ddf_col <- broadcast(1:6,
-                       list(axis1 = letters[1:2],
-                            axis2 = letters[1:3]))
+  ddf_col <- broadcast(1:6, list(axis1 = letters[1:2], axis2 = letters[1:3]))
   expect_equal(nrow(ddf_col), 6)
   expect_equal(ncol(ddf_col), NULL)
 
@@ -11,9 +9,7 @@ test_that("nrow-ncol", {
 })
 
 test_that("row-colnames", {
-  ddf_col <- broadcast(1:6,
-                       list(axis1 = letters[1:2],
-                            axis2 = letters[1:3]))
+  ddf_col <- broadcast(1:6, list(axis1 = letters[1:2], axis2 = letters[1:3]))
   expect_equal(rownames(ddf_col), NULL)
   expect_equal(colnames(ddf_col), NULL)
 
